/**
 * @function _datasource
 */

"use strict";

const fs = require('fs'),
    path = require('path'),
    arrayfilter = require('arrayfilter'),
    stringcase = require('stringcase'),
    _isModule = require('./_is_module');

/** @lends _datasource */
function _datasource(dirname) {
    let datasource = {};
    fs.readdirSync(dirname)
        .filter(arrayfilter.patternReject(/^index\./))
        .filter(arrayfilter.patternReject(/^\./))
        .filter(arrayfilter.patternReject(/^\_/))
        .map((filename) => {
            return path.resolve(dirname, filename);
        })
        .filter(_isModule)
        .forEach((filename) => {
            let name = path.basename(filename, path.extname(filename));
            Object.defineProperty(datasource, stringcase.camelcase(name), {
                get: function () {
                    return require(filename);
                },
                enumerable: true
            })
        });
    return datasource;
}

module.exports = _datasource;
