/**
 * Create a directory module index.
 * @function apemanmodule
 * @param {string} dirname - Directory path which contains locale messages.
 * @param {object} [options] - Optional settings.
 * @returns {object} modules
 */

"use strict";

const argx = require('argx'),
    extend = require('extend'),
    _datasource = require('./_datasource');

/** @lends apemanmodule */
function apemanmodule(dirname, options) {
    let args = argx(arguments);
    options = args.pop('object') || {};
    dirname = args.shift('string');

    let datasource = _datasource(dirname);

    function modules(name) {
        return datasource[name];
    }

    Object.keys(datasource).forEach((key) => {
        Object.defineProperty(modules, key, {
            get: function () {
                return datasource[key];
            },
            enumerable: true
        })
    });

    return modules;
}

module.exports = apemanmodule;